import * as express from 'express';
import * as common from '../../common/providers/https';
import { HttpsFunction, Runnable } from '../cloud-functions';
import { DeploymentOptions } from '../function-configuration';
export declare type Request = common.Request;
export declare type CallableContext = common.CallableContext;
export declare type FunctionsErrorCode = common.FunctionsErrorCode;
export declare type HttpsError = common.HttpsError;
/**
 * Handle HTTP requests.
 * @param handler A function that takes a request and response object,
 * same signature as an Express app.
 */
export declare function onRequest(handler: (req: Request, resp: express.Response) => void | Promise<void>): HttpsFunction;
/**
 * Declares a callable method for clients to call using a Firebase SDK.
 * @param handler A method that takes a data and context and returns a value.
 */
export declare function onCall(handler: (data: any, context: CallableContext) => any | Promise<any>): HttpsFunction & Runnable<any>;
/** @hidden */
export declare function _onRequestWithOptions(handler: (req: Request, resp: express.Response) => void | Promise<void>, options: DeploymentOptions): HttpsFunction;
/** @hidden */
export declare function _onCallWithOptions(handler: (data: any, context: CallableContext) => any | Promise<any>, options: DeploymentOptions): HttpsFunction & Runnable<any>;
